@@ -2,13 +2,27 @@ from API_Gen.base_generator import BaseGenerator
 
 
 class SanicGenerator(BaseGenerator):
+    '''
+    SanicGenerator will create end-point handlers for Sanic framework applications
+    - Child class of BaseGenerator
+    ...
+
+    Methods
+    -------
+
+    def _write_imports_to_api(self):
+        writes import statements to api file
+
+    def _write_methods_to_api(self):
+        writes url handlers to api file
+    '''
+    FRAMEWORK_NAME = 'sanic'
 
     def __init__(self, api_info) -> None:
         super().__init__(api_info)
 
-    # Intitlaizes the wepapp.py file
     def _write_imports_to_api(self):
-        self.api_import_placeholder = "from . import app\
+        self.api_import_placeholder = f"from . import {self.framework_object}\
                                       \nfrom sanic import json\
                                       \nfrom . import DUMMY_RESPONSE_JSON\n\n"
 
@@ -19,7 +33,7 @@ class SanicGenerator(BaseGenerator):
         try:
             for api in self.api_info['api_list']:
 
-                self.api_method_placeholder += f"@app.{api['HTTP_method'].lower()}('{api['path']}')\
+                self.api_method_placeholder += f"@{self.framework_object}.{api['HTTP_method'].lower()}('{api['path']}')\
                                                  \nasync def {api['method_handler_name']}(request):\
                                                  \n\treturn json(DUMMY_RESPONSE_JSON['{api['method_handler_name']}'])\n\n"
 
@@ -32,4 +46,4 @@ class SanicGenerator(BaseGenerator):
             self._write_to_dummy_response(self.dummy_response_placeholder)
 
         except KeyError as e:
-            print(e)
+            raise KeyError(f"Invalid key in Json '{e.args[0]}' ")
